@@ -51,7 +51,7 @@
 
 (define DenemoWholeMeasureRestTag "WholeMeasureRest") ;several commands have to coordinate there behavior around whole measure rests, which are not built-in
 (define DenemoWholeMeasureRestCommand d-WholeMeasureRest)
-(define DenemoWholeMeasureRestParams 'WholeMeasureRest::Params)  ;these three must match for this to work.
+(define DenemoWholeMeasureRestParams 'WholeMeasureRest::params)  ;these three must match for this to work.
 
 (define DenemoKeypressActivatedCommand #f) ;;;is true while a keyboard shortcut is invoking a script, unless the script has set it to #f
 
@@ -156,8 +156,21 @@
 (define cue-Delete (_ "Delete"))
 (define cue-Edit (_ "Edit"))
 (define cue-RestorePosition (_ "Restore Position")) 
+(define cue-NudgePosition (_ "Nudge Position")) 
+
 ;(define cue- "")
 
+(define (GetNudge)
+    (let ((offsetx "0")(offsety "0"))
+            (set! offsetx (d-GetUserInput (_ "Offset Position") (_ "Amount (+/-) to nudge in horizontal direction") offsetx))
+            (if offsetx
+                (begin
+                    (set! offsety (d-GetUserInput (_ "Offset Position") (_ "Amount (+/-) to nudge in vertical direction") offsetx))
+                    (if offsety
+                        (cons offsetx offsety)
+                        #f)
+                #f))))
+
 ;;;;;;;;;;;;;;;; Double-Stroke for sequencing keypresses. By Nils Gey June 2010
 ;One parameter for the GUI-version or help window. This is the version that appears if someone clicks on the menu version.
 ;Ten optional parameters, each a pair with car = Pretty String for fallback-gui, cdr = scheme-command. Give (cons "" False) to skip over one slot.
@@ -846,7 +859,7 @@
   (d-Directive-standalone  "DenemoLink")
   (d-DirectivePut-standalone-postfix "DenemoLink" (string-append "%{" filepos "%}"))
   (d-DirectivePut-standalone-minpixels "DenemoLink" 30)
-  (d-DirectivePut-standalone-graphic "DenemoLink" "\n⬁\ndenemo\n36")
+  (d-DirectivePut-standalone-graphic "DenemoLink" "\n⬁\ndenemo\n24")
   (d-DirectivePut-standalone-gy "DenemoLink" 10)
   (d-MoveCursorRight)
   (d-RefreshDisplay))
@@ -936,7 +949,48 @@
         (let ((filename
             (string-append DENEMO_LOCAL_ACTIONS_DIR "//graphics//" name ".eps")))
             (if (d-FileExists filename)
-                (d-CustomOrnamentDefinition (list name filename 2))
-                #f))))
+                    (begin
+                        (d-WarningDialog (_ "This definition is not loaded ... trying to load"))
+                        (d-CustomOrnamentDefinition (list name filename 2))
+                        )
+                    #f))))
                 
                 
+;;;;;;;;;;
+(define (ToggleOrnament name params)
+(let ((tag (string-append "Toggle" (string-upcase name 0  1)))(filename (scheme-escape (string-append DENEMO_GRAPHICS_DIR name ".eps"))))
+                        (ChordOrnament tag (string-append "\\" name)   params   name)
+(if (not (d-Directive-score? (string-append "Allow\n" name)))
+    (begin
+        (d-LilyPondDefinition (cons name (string-append "\\tweak outside-staff-priority #50 -\\markup {\\epsfile #X #2 #\"" filename "\""   "}" )))
+        (d-DirectivePut-score-data (string-append "Allow\n" name) (string-append "(list \"" name "\" \"" filename  "\" \"2\")"))))))
+ 
+;;;;;;;;;
+(define (GetDefinitionDirectives)
+    (define directives '())
+    (let loop ((count 1))
+        (define good-tag (d-DirectiveGetNthTag-score count))
+        (if good-tag 
+            (begin
+                (if (string-prefix? "Allow\n" good-tag)
+                    (set! directives (cons good-tag directives)))
+                (loop (1+ count)))))
+    directives)
+
+(define (GetDefinitionDataFromUser)
+    (let  ((directives '())(definitions #f))
+        (define (get-second-line text)
+            (let ((thelist (string-split text #\newline)))
+                (if (> (length thelist) 1)
+                (list-ref thelist 1)
+                "")))
+        (define (extract-data tag)
+            (define name (get-second-line tag))
+            (cons name (d-DirectiveGet-score-data tag)))
+        (set! directives (GetDefinitionDirectives))
+
+        (if (not (null? directives))
+            (set! definitions (map extract-data directives)))
+        (if definitions
+                (RadioBoxMenuList definitions)
+                #f)))
