@@ -6,9 +6,10 @@
 ;Variable descriptions:
 ;SplitAll set to #f allows user to decide whether to split across barlines; set to #t, splits always.
 ;TupletScaleFactor: e.g. if we're inside a triplet, scale durations by 2/3
+;IgnoreDurationError set if a measure is marked as having an allowable duration discrepancy, marking is done with a directive of tag "!"
 (define ReBar::return #f)
 (let ( (Input1 #f) (Input2 #f) (InitialTimeSig 1) (ScanAllStaffs #f) (TupletScaleFactor 1)  
-(SplitAll #f))
+(SplitAll #f)(IgnoreDurationError #f))
     
 ;MakeBlankRestDuration: makes a tied rest conglomerate of total duration Duration.
 ;IsConsecutive is set to #t when it recurses in order to make it add a dot instead of adding the next TryDuration.  Externally, call it always set to #f
@@ -203,7 +204,9 @@
             )
             
             (if (equal? (d-GetType) "LILYDIRECTIVE")
-                (set! NoteBeat (/ (d-GetDurationInTicks) 1536))
+                (begin
+                    (set! NoteBeat (/ (d-GetDurationInTicks) 1536))
+                    (set! IgnoreDurationError (d-Directive-standalone? "!"))) ;;This tag tells Denemo to ignore duration errors in this measure.
             )
             (if (equal? (d-GetType) "CHORD" ) 
                 (if (not (d-ToggleGrace "query="))  ;if it's not a grace, continue; otherwise, leave it as 0.                   
@@ -234,19 +237,24 @@
         )
     )
     ;here's the actual algorithm
+     (set! IgnoreDurationError #f)
     (while (d-PrevObjectInMeasure)) ;go to beginning of measure
     (set! Counter (+ Counter (GetNoteBeat)) );read the first note in to get started...NOTE: if GetNoteBeat= #f this will terminate execution.
     (LoopThroughBar)    ;then loop through the rest of the bar until counter equals or overshoots the measure size in TimeSig,
                     ; or the measure's done being processed
-        (disp "check Counter " Counter " and time sig " TimeSig "ok")
+       ; (disp "check Counter " Counter " and time sig " TimeSig "and " IgnoreDurationError " ok")
         ;;ticks have granularity of 1 so we cannot accept a 1 discrepancy as meaning anything once we have reached a certain number of ticks - how many I am not sure, but try 383, fails with septuplet, try 255
     (if (and (None?) (not Pad?))
         (set! Counter TimeSig))
+    (if IgnoreDurationError
+        (begin
+           
+            (set! Counter TimeSig)))
     (let ((top (numerator Counter)) (bottom (denominator Counter)))
         ;(disp "We have top " top " bottom " bottom " div "  (/ (1+ top) bottom) " ok")
         (if  (and (> top 254) (equal? TimeSig (/ (1+ top) bottom)))
             (set! Counter (/ (1+ top) bottom))))
-(disp "Set Counter " Counter "\n")          
+;(disp "Set Counter " Counter "\n")          
           (if (< Counter TimeSig) ;if measure too small, (going back first)
             (if Pad?    ; and the user wants us to pad,
                 (begin
@@ -284,7 +292,7 @@
             )
             ;if it wasn't too small...
 
-            (if  (equal? Counter TimeSig) ; and if measure is exactly full now...
+            (if (and (not IgnoreDurationError)  (equal? Counter TimeSig)) ; and if measure is exactly full now... or we are counting it as
                 (if (NextBreakInMeasure) ;see if there's extra stuff that has duration,
                     (if MergeAndSplit?  ;if there IS and we're supposed to merge/split...
                         (begin
@@ -356,7 +364,7 @@
                         )                   
                     )
                     
-                    #f  ;just return false if they don't want to Merge/Split.
+                    IgnoreDurationError  ;just return false if they don't want to Merge/Split, unless it is ignored
                 )
             )
             
