@@ -32,9 +32,15 @@
                         (set! CheckScore::return CheckBeamsInMeasure::return)))
                 (if (not CheckScore::return)
                     (if (d-MoveToMeasureRight)
-                        (measure))
-                     (if (or (d-MoveToVoiceDown) (d-MoveToStaffDown))
-                    (staff)))))))
+                      (measure)
+                      (if (or (d-MoveToVoiceDown) (d-MoveToStaffDown))
+                           (staff))))))))
+                           
+     (if (not CheckScore::return)                      
+               (begin
+               		(d-CheckTimeSignatures #t)
+               		(set! CheckScore::return CheckTimeSignatures::return)))            
+                           
     (if (not CheckScore::return)
           (let staff ()
             (d-ReBar #t)
@@ -43,6 +49,13 @@
                 (begin 
                     (if (or (d-MoveToVoiceDown) (d-MoveToStaffDown))
                     (staff))))))
+                    
+    (if (not CheckScore::return)
+        (begin
+            (d-CheckBraces 'noninteractive)
+            (set! CheckScore::return CheckBraces::Return)))
+                        
+                                        
     (if (and (not CheckScore::return) (d-NextMovement))
             (movement)))
             
