@@ -9,18 +9,18 @@
 #include <stdint.h>
 #include "command/commandfuncs.h"
 #include "display/calculatepositions.h"
-#include "command/chordops.h"
+#include "command/chord.h"
 #include "command/contexts.h"
 #include "display/draw.h"
-#include "command/measureops.h"
+#include "command/measure.h"
 #include "audio/midi.h"
-#include "command/objops.h"
+#include "command/object.h"
 #include "ui/moveviewport.h"
-#include "command/selectops.h"
-#include "command/staffops.h"
+#include "command/select.h"
+#include "command/staff.h"
 #include "core/utils.h"
-#include "command/tupletops.h"
-#include "command/graceops.h"
+#include "command/tuplet.h"
+#include "command/grace.h"
 #include "audio/instrumentname.h"
 #include "export/file.h"
 #include "export/exportlilypond.h"
@@ -106,7 +106,7 @@ beamandstemdirhelper (DenemoMovement * si)
   DenemoObject *theclef = NULL;
   if (si->currentmeasure->prev)
     {
-      objnode *curobj = lastobjnode (si->currentmeasure->prev);
+      objnode *curobj = measure_last_obj_node (si->currentmeasure->prev);
       if (curobj)
         theclef = get_clef_before_object (curobj);
     }
@@ -130,12 +130,12 @@ setcurrents (DenemoMovement * si)
 {
   if (((DenemoStaff *) si->currentstaff->data)->nummeasures >= si->currentmeasurenum)
     {
-      si->currentmeasure = g_list_nth (firstmeasurenode (si->currentstaff), si->currentmeasurenum - 1);
+      si->currentmeasure = g_list_nth (staff_first_measure_node (si->currentstaff), si->currentmeasurenum - 1);
     }
   else
     {
       g_debug ("Setting measure to %d which is last in Staff\n", ((DenemoStaff *) si->currentstaff->data)->nummeasures);
-      si->currentmeasure = g_list_nth (firstmeasurenode (si->currentstaff), ((DenemoStaff *) si->currentstaff->data)->nummeasures - 1);
+      si->currentmeasure = g_list_nth (staff_first_measure_node (si->currentstaff), ((DenemoStaff *) si->currentstaff->data)->nummeasures - 1);
       si->currentmeasurenum = ((DenemoStaff *) si->currentstaff->data)->nummeasures;
 
     }
@@ -291,8 +291,8 @@ object_insert (DenemoProject * gui, DenemoObject * mudela_obj_new)
   if (mudela_obj_new->type == CLEF)
     {
       reset_cursor_stats (si);
-      fixnoteheights ((DenemoStaff *) si->currentstaff->data);
-      beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
+      staff_fix_note_heights ((DenemoStaff *) si->currentstaff->data);
+      staff_beams_and_stems_dirs ((DenemoStaff *) si->currentstaff->data);
       find_xes_in_all_measures (si);
     }
 
@@ -488,7 +488,7 @@ swapstaffs (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam *
               gui->movement->currentstaff->prev->data = temp;
               gui->movement->currentstaffnum--;
               gui->movement->currentstaff = gui->movement->currentstaff->prev;
-              setcurrentprimarystaff (gui->movement);
+              staff_set_current_primary (gui->movement);
               setcurrents (gui->movement);
               move_viewport_up (gui);
               score_status (gui, TRUE);
@@ -522,7 +522,7 @@ splitstaffs (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam *
         nextstaff->voicecontrol = DENEMO_SECONDARY | DENEMO_PRIMARY;
       else
         warningdialog (_("There is no voice below this one on this staff"));
-      setcurrentprimarystaff (gui->movement);
+      staff_set_current_primary (gui->movement);
       setcurrents (gui->movement);
       move_viewport_up (gui);
       score_status (gui, TRUE);
@@ -549,7 +549,7 @@ joinstaffs (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam *
       take_snapshot ();
       DenemoStaff *thestaff = (DenemoStaff *) gui->movement->currentstaff->data;
       thestaff->voicecontrol = DENEMO_SECONDARY;
-      setcurrentprimarystaff (gui->movement);
+      staff_set_current_primary (gui->movement);
       setcurrents (gui->movement);
       move_viewport_up (gui);
       score_status (gui, TRUE);
@@ -585,7 +585,7 @@ govoiceup (DenemoScriptParam * param, gboolean extend_selection)
       hide_lyrics ();
       gui->movement->currentstaffnum--;
       gui->movement->currentstaff = gui->movement->currentstaff->prev;
-      setcurrentprimarystaff (gui->movement);
+      staff_set_current_primary (gui->movement);
       setcurrents (gui->movement);
       show_lyrics ();
       move_viewport_down (gui);
@@ -625,7 +625,7 @@ gostaffup (DenemoScriptParam * param, gboolean extend_selection)
       hide_lyrics ();
       gui->movement->currentstaffnum--;
       gui->movement->currentstaff = gui->movement->currentstaff->prev;
-      setcurrentprimarystaff (gui->movement);
+      staff_set_current_primary (gui->movement);
       setcurrents (gui->movement);
       if (extend_selection)
         calcmarkboundaries (gui->movement);
@@ -667,7 +667,7 @@ govoicedown (DenemoScriptParam * param, gboolean extend_selection)
       hide_lyrics ();
       gui->movement->currentstaffnum++;
       gui->movement->currentstaff = gui->movement->currentstaff->next;
-      setcurrentprimarystaff (gui->movement);
+      staff_set_current_primary (gui->movement);
       setcurrents (gui->movement);
       if (extend_selection)
         calcmarkboundaries (gui->movement);
@@ -740,7 +740,7 @@ gostaffdown (DenemoScriptParam * param, gboolean extend_selection)
       hide_lyrics ();
       gui->movement->currentstaffnum++;
       gui->movement->currentstaff = gui->movement->currentstaff->next;
-      setcurrentprimarystaff (gui->movement);
+      staff_set_current_primary (gui->movement);
       setcurrents (gui->movement);
       if (extend_selection)
         calcmarkboundaries (gui->movement);
@@ -1563,7 +1563,12 @@ insertion_point (DenemoMovement * si)
         {
             objnode *objnode = si->currentmeasure->next->data;
             DenemoObject *obj = objnode->data;
-            if ((obj->type == TIMESIG) && (objnode->next==NULL))
+            while (obj && (obj->type != CHORD)) 
+                { 
+                    objnode=objnode->next;obj = objnode?objnode->data:NULL;
+                }
+                
+            if ((obj==NULL) || (obj->type != CHORD))
                 next_measure = TRUE;         
         }
   }
@@ -1582,13 +1587,17 @@ insertion_point (DenemoMovement * si)
         }
       else
         si->currentmeasure = si->currentmeasure->next;
+        
+        
+        
+        
       if (Denemo.project->mode & (INPUTRHYTHM))
         signal_measure_end ();
       /* Now the stuff that needs to be done for each case */
       si->currentmeasurenum++;
       si->currentobject = (objnode *) si->currentmeasure->data;
       si->cursor_x = 0;
-      if(si->currentobject && (((DenemoObject *)si->currentobject->data)->type == TIMESIG))
+      while(si->currentobject && (((DenemoObject *)si->currentobject->data)->type != CHORD))
         {
             si->currentobject = si->currentobject->next;
             si->cursor_x++;
@@ -1752,32 +1761,32 @@ dnm_inserttuplet (DenemoProject * gui, tuplet_type type)
   switch (type)
     {
     case DUPLET:
-      mudela_obj_new = newtupopen (3, 2);
+      mudela_obj_new = tuplet_open_new (3, 2);
       break;
     case TRIPLET:
-      mudela_obj_new = newtupopen (2, 3);
+      mudela_obj_new = tuplet_open_new (2, 3);
       break;
     case QUADTUPLET:
-      mudela_obj_new = newtupopen (3, 4);
+      mudela_obj_new = tuplet_open_new (3, 4);
       break;
     case QUINTUPLET:
-      mudela_obj_new = newtupopen (4, 5);
+      mudela_obj_new = tuplet_open_new (4, 5);
       break;
     case SEXTUPLET:
-      mudela_obj_new = newtupopen (4, 6);
+      mudela_obj_new = tuplet_open_new (4, 6);
       break;
     case SEPTUPLET:
-      mudela_obj_new = newtupopen (4, 7);
+      mudela_obj_new = tuplet_open_new (4, 7);
       break;
     default:
-      mudela_obj_new = newtupopen (2, 3);
+      mudela_obj_new = tuplet_open_new (2, 3);
       break;
     }
   //g_debug ("Cursor pos %d (Before tup open)\n", si->cursor_x);
   object_insert (gui, mudela_obj_new);
   //g_debug ("Cursor pos %d (After tup open, before tup close)\n",         si->cursor_x);
   /* Add the closing bracket */
-  object_insert (gui, newtupclose ());
+  object_insert (gui, tuplet_close_new ());
   //g_debug ("Cursor pos %d (After tup close)\n", si->cursor_x);
   si->cursor_x--;
   //g_debug ("Cursor pos %d( After move back)\n", si->cursor_x);
@@ -2133,10 +2142,10 @@ insertmeasurebefore (GtkAction* action, G_GNUC_UNUSED DenemoScriptParam* param)
 void
 appendmeasures (DenemoMovement * si, gint number)
 {
-  dnm_addmeasures (si, g_list_length (firstmeasurenode (si->currentstaff)), number, FALSE);
+  dnm_addmeasures (si, g_list_length (staff_first_measure_node (si->currentstaff)), number, FALSE);
   /* Reset these two variables because si->currentmeasure and
    * si->currentobject may now be pointing to dead data */
-  si->currentmeasure = g_list_nth (firstmeasurenode (si->currentstaff), si->currentmeasurenum - 1);
+  si->currentmeasure = g_list_nth (staff_first_measure_node (si->currentstaff), si->currentmeasurenum - 1);
   si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data, si->cursor_x - (si->cursor_appending == TRUE));
   set_rightmeasurenum (si);
   displayhelper (Denemo.project);
@@ -2147,10 +2156,10 @@ appendmeasures (DenemoMovement * si, gint number)
 void
 appendmeasurestoentirescore (DenemoMovement * si, gint number)
 {
-  dnm_addmeasures (si, g_list_length (firstmeasurenode (si->currentstaff)), number, TRUE);
+  dnm_addmeasures (si, g_list_length (staff_first_measure_node (si->currentstaff)), number, TRUE);
   /* Reset these two variables because si->currentmeasure and
    * si->currentobject may now be pointing to dead data */
-  si->currentmeasure = g_list_nth (firstmeasurenode (si->currentstaff), si->currentmeasurenum - 1);
+  si->currentmeasure = g_list_nth (staff_first_measure_node (si->currentstaff), si->currentmeasurenum - 1);
   si->currentobject = g_list_nth ((objnode *) si->currentmeasure->data, si->cursor_x - (si->cursor_appending == TRUE));
   set_rightmeasurenum (si);
   /* update_hscrollbar (si); */
@@ -2173,7 +2182,7 @@ delete_staff_before (GtkAction * action, DenemoScriptParam * param)
   DenemoProject *gui = Denemo.project;
   if (staffup (action, param))
     {
-      deletestaff (gui, TRUE);
+      staff_delete (gui, TRUE);
     }
 }
 
@@ -2189,7 +2198,7 @@ delete_staff_after (GtkAction * action, DenemoScriptParam * param)
   DenemoProject *gui = Denemo.project;
   if (staffdown (action, param))
     {
-      deletestaff (gui, TRUE);
+      staff_delete (gui, TRUE);
     }
 }
 
@@ -2203,7 +2212,7 @@ void
 delete_staff_current (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam * param)
 {
   DenemoProject *gui = Denemo.project;
-  deletestaff (gui, TRUE);
+  staff_delete (gui, TRUE);
 }
 
 
@@ -2381,16 +2390,16 @@ dnm_deleteobject (DenemoMovement * si)
 /* here we have to re-validate leftmost clef e.g. find_leftmost_allcontexts (gui->movement);
  which seems to be done... */
           delete_object_helper (si);
-          fixnoteheights ((DenemoStaff *) si->currentstaff->data);
-          beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
+          staff_fix_note_heights ((DenemoStaff *) si->currentstaff->data);
+          staff_beams_and_stems_dirs ((DenemoStaff *) si->currentstaff->data);
           find_xes_in_all_measures (si);
           break;
         case KEYSIG:
           /* Doesn't automatically delete sibling key signatures, though
            * I probably will have it do so soon */
           delete_object_helper (si);
-          beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
-          showwhichaccidentalswholestaff ((DenemoStaff *) si->currentstaff->data);
+          staff_beams_and_stems_dirs ((DenemoStaff *) si->currentstaff->data);
+          staff_show_which_accidentals ((DenemoStaff *) si->currentstaff->data);
           find_xes_in_all_measures (si);
           break;
         case TIMESIG:
@@ -2401,7 +2410,7 @@ dnm_deleteobject (DenemoMovement * si)
            * if in the conventional, first, position */
           for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
             {
-              curmeasure = g_list_nth (firstmeasurenode (curstaff), si->currentmeasurenum - 1);
+              curmeasure = g_list_nth (staff_first_measure_node (curstaff), si->currentmeasurenum - 1);
               if (curmeasure && curmeasure->data)
                 {
                   DenemoObject *first_obj = ((objnode *) curmeasure->data)->data;
@@ -2409,7 +2418,7 @@ dnm_deleteobject (DenemoMovement * si)
                   if (first_obj && first_obj->type == TIMESIG)
                     {
                       remove_object (curmeasure, (objnode *) curmeasure->data);
-                      beamsandstemdirswholestaff ((DenemoStaff *) curstaff->data);
+                      staff_beams_and_stems_dirs ((DenemoStaff *) curstaff->data);
                     }
                 }
             }
@@ -2419,7 +2428,7 @@ dnm_deleteobject (DenemoMovement * si)
           break;
         case STEMDIRECTIVE:
           delete_object_helper (si);
-          beamsandstemdirswholestaff ((DenemoStaff *) si->currentstaff->data);
+          staff_beams_and_stems_dirs ((DenemoStaff *) si->currentstaff->data);
           find_xes_in_all_measures (si);
           break;
         case DYNAMIC:
@@ -2498,7 +2507,7 @@ toggle_tie (G_GNUC_UNUSED GtkAction * action, G_GNUC_UNUSED DenemoScriptParam *
   DenemoProject *gui = Denemo.project;
   DenemoMovement *si = gui->movement;
   DenemoObject *curmudelaobj = (DenemoObject *) (gui->movement->currentobject ? gui->movement->currentobject->data : NULL);
-  if (curmudelaobj && curmudelaobj->type == CHORD && ((chord *) curmudelaobj->object)->notes)
+  if (curmudelaobj && curmudelaobj->type == CHORD && ((((chord *) curmudelaobj->object)->notes) ||  ((chord *) curmudelaobj->object)->is_tied))
     {
       store_for_undo_change (si, curmudelaobj);
       ((chord *) curmudelaobj->object)->is_tied ^= 1;
