@@ -7,7 +7,7 @@
 #include "core/kbd-custom.h"
 #include "command/keyresponses.h"
 #include "core/utils.h"
-#include "command/tupletops.h"
+#include "command/tuplet.h"
 #include "core/view.h"
 #include "command/commandfuncs.h"
 #include "core/kbd-custom.h"
@@ -787,58 +787,6 @@ insert_blankchord_8key (GtkAction* action, DenemoScriptParam *param)
   insert_blankchord_xkey(8, param);
 }
 
-
-void
-insert_duplet (GtkAction* action, DenemoScriptParam *param)
-{
-  dnm_inserttuplet (Denemo.project, DUPLET);
-}
-
-void
-insert_triplet (GtkAction* action, DenemoScriptParam *param)
-{
-  dnm_inserttuplet (Denemo.project, TRIPLET);
-}
-
-void
-start_triplet (GtkAction* action, DenemoScriptParam *param)
-{
-  insertion_point (Denemo.project->movement);
-  object_insert (Denemo.project, newtupopen (2, 3));
-}
-
-void
-end_tuplet (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, newtupclose ());
-}
-
-void
-insert_quadtuplet (GtkAction* action, DenemoScriptParam *param)
-{
-  dnm_inserttuplet (Denemo.project, QUADTUPLET);
-}
-
-void
-insert_quintuplet (GtkAction* action, DenemoScriptParam *param)
-{
-  dnm_inserttuplet (Denemo.project, QUINTUPLET);
-}
-
-void
-insert_sextuplet (GtkAction* action, DenemoScriptParam *param)
-{
-  dnm_inserttuplet (Denemo.project, SEXTUPLET);
-}
-
-void
-insert_septuplet (GtkAction* action, DenemoScriptParam *param)
-{
-  dnm_inserttuplet (Denemo.project, SEPTUPLET);
-}
-
-
-
 gboolean
 add_tone_key (GtkAction* action, DenemoScriptParam *param)
 {
@@ -1029,746 +977,6 @@ change_pitch (GtkAction* action, DenemoScriptParam *param)
 
 }
 
-
-
-
-/**
- * Wrapper function to create new treble clef and insert into the score
- */
-void
-newcleftreble (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_TREBLE_CLEF));
-}
-
-/**
- * Wrapper function to create new bass clef and insert into the score
- */
-void
-newclefbass (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_BASS_CLEF));
-}
-
-/**
- * Wrapper function to create new alto clef and insert into the score
- */
-void
-newclefalto (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_ALTO_CLEF));
-}
-
-/**
- * Wrapper function to create new treble_8 clef and insert into the score
- */
-void
-newclefg8 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_G_8_CLEF));
-}
-
-/**
- * Wrapper function to create new bass_8 clef and insert into the score
- */
-void
-newcleff8 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_F_8_CLEF));
-}
-
-/**
- * Wrapper function to create new tenor clef and insert into the score
- */
-void
-newcleftenor (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_TENOR_CLEF));
-}
-
-/**
- * Wrapper function to create new soprano clef and insert into the score
- */
-void
-newclefsoprano (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_SOPRANO_CLEF));
-}
-
-/**
- * Wrapper function to create new french clef and insert into the score
- */
-void
-newcleffrench (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newclefobj (DENEMO_FRENCH_CLEF));
-}
-
-/**
- * Wrapper function to create new 4/4 time sig and insert into the score
- */
-void
-newtimesig44 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (4, 4));
-}
-
-/**
- * Wrapper function to create new 2/4 time sig and insert into the score
- */
-void
-newtimesig24 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (2, 4));
-}
-
-/**
- * Wrapper function to create new 3/4 time sig and insert into the score
- */
-void
-newtimesig34 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (3, 4));
-}
-
-/**
- * Wrapper function to create new 6/4 time sig and insert into the score
- */
-void
-newtimesig64 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (6, 4));
-}
-
-/**
- * Wrapper function to create new 5/4 time sig and insert into the score
- */
-void
-newtimesig54 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (5, 4));
-}
-
-/**
- * Wrapper function to create new 3/8 time sig and insert into the score
- */
-void
-newtimesig38 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (3, 8));
-}
-
-/**
- * Wrapper function to create new 6/8 time sig and insert into the score
- */
-void
-newtimesig68 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (6, 8));
-}
-
-/**
- * Wrapper function to create new 9/8 time sig and insert into the score
- */
-void
-newtimesig98 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (9, 8));
-}
-
-/**
- * Wrapper function to create new 12/8 time sig and insert into the score
- */
-void
-newtimesig128 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (12, 8));
-}
-
-/**
- * Wrapper function to create new 2/2 time sig and insert into the score
- */
-void
-newtimesig22 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (2, 2));
-}
-
-/**
- * Wrapper function to create new 3/2 time sig and insert into the score
- */
-void
-newtimesig32 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (3, 2));
-}
-
-/**
- * Wrapper function to create new 4/2 time sig and insert into the score
- */
-void
-newtimesig42 (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newtimesigobj (4, 2));
-}
-
-
-
-void
-newkeysigcmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (0, 1, 0));
-}
-
-void
-newkeysiggmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (1, 1, 0));
-}
-
-void
-newkeysigdmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (2, 1, 0));
-}
-
-void
-newkeysigamaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (3, 1, 0));
-}
-
-void
-newkeysigemaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (4, 1, 0));
-}
-
-void
-newkeysigbmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (5, 1, 0));
-}
-
-void
-newkeysigfsharpmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (6, 1, 0));
-}
-
-void
-newkeysigcsharpmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (7, 1, 0));
-}
-
-void
-newkeysigfmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-1, 1, 0));
-}
-
-void
-newkeysigbflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-2, 1, 0));
-}
-
-void
-newkeysigeflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-3, 1, 0));
-}
-
-void
-newkeysigaflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-4, 1, 0));
-}
-
-void
-newkeysigdflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-5, 1, 0));
-}
-
-void
-newkeysiggflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-6, 1, 0));
-}
-
-void
-newkeysigcflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-7, 1, 0));
-}
-
-void
-newkeysigamin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (0, 0, 0));
-}
-
-void
-newkeysigemin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (1, 0, 0));
-}
-
-void
-newkeysigbmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (2, 0, 0));
-}
-
-void
-newkeysigfsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (3, 0, 0));
-}
-
-void
-newkeysigcsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (4, 0, 0));
-}
-
-void
-newkeysiggsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (5, 0, 0));
-}
-
-void
-newkeysigdsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (6, 0, 0));
-}
-
-void
-newkeysigasharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (7, 0, 0));
-}
-
-void
-newkeysigdmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-1, 0, 0));
-}
-
-void
-newkeysiggmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-2, 0, 0));
-}
-
-void
-newkeysigcmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-3, 0, 0));
-}
-
-void
-newkeysigfmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-4, 0, 0));
-}
-
-void
-newkeysigbflatmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-5, 0, 0));
-}
-
-void
-newkeysigeflatmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-6, 0, 0));
-}
-
-void
-newkeysigaflatmin (GtkAction* action, DenemoScriptParam *param)
-{
-  object_insert (Denemo.project, dnm_newkeyobj (-7, 0, 0));
-}
-
-
-//Functions to set the initial key signature
-void
-setkeysigcmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 0, 1);
-  //displayhelper(si);
-}
-
-void
-setkeysiggmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 1, 1);
-  //displayhelper(si);
-}
-
-void
-setkeysigdmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 2, 1);
-}
-
-void
-setkeysigamaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 3, 1);
-}
-
-void
-setkeysigemaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 4, 1);
-}
-
-void
-setkeysigbmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 5, 1);
-}
-
-void
-setkeysigfsharpmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 6, 1);
-}
-
-void
-setkeysigcsharpmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 7, 1);
-}
-
-void
-setkeysigfmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -1, 1);
-}
-
-void
-setkeysigbflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -2, 1);
-}
-
-void
-setkeysigeflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -3, 1);
-}
-
-void
-setkeysigaflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -4, 1);
-}
-
-void
-setkeysigdflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -5, 1);
-}
-
-void
-setkeysiggflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -6, 1);
-}
-
-void
-setkeysigcflatmaj (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -7, 1);
-}
-
-void
-setkeysigamin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 0, 0);
-}
-
-void
-setkeysigemin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 1, 0);
-}
-
-void
-setkeysigbmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 2, 0);
-}
-
-void
-setkeysigfsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 3, 0);
-}
-
-void
-setkeysigcsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 4, 0);
-}
-
-void
-setkeysiggsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 5, 0);
-}
-
-void
-setkeysigdsharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 6, 0);
-}
-
-void
-setkeysigasharpmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, 7, 0);
-}
-
-void
-setkeysigdmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -1, 0);
-}
-
-void
-setkeysiggmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -2, 0);
-}
-
-void
-setkeysigcmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -3, 0);
-}
-
-void
-setkeysigfmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -4, 0);
-}
-
-void
-setkeysigbflatmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -5, 0);
-}
-
-void
-setkeysigeflatmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -6, 0);
-}
-
-void
-setkeysigaflatmin (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  dnm_setinitialkeysig (curstaff, -7, 0);
-}
-
-
-void
-settimesig22 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 2, 2, TRUE);
-}
-
-void
-settimesig42 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 4, 2, TRUE);
-}
-
-void
-settimesig32 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 3, 2, TRUE);
-}
-
-void
-settimesig44 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 4, 4, TRUE);
-}
-
-void
-settimesig54 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 5, 4, TRUE);
-}
-
-void
-settimesig24 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 2, 4, TRUE);
-}
-
-void
-settimesig34 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 3, 4, TRUE);
-}
-
-void
-settimesig68 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 6, 8, TRUE);
-}
-
-void
-settimesig128 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 12, 8, TRUE);
-}
-
-void
-settimesig38 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 3, 8, TRUE);
-}
-
-void
-settimesig98 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 9, 8, TRUE);
-}
-
-void
-settimesig64 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialtimesig (Denemo.project->movement, curstaff, 6, 4, TRUE);
-}
-
-void
-setcleftreble (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_TREBLE_CLEF);
-}
-
-void
-setclefbass (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_BASS_CLEF);
-}
-
-void
-setclefg8 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_G_8_CLEF);
-}
-
-void
-setcleff8 (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_F_8_CLEF);
-}
-
-void
-setclefalto (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_ALTO_CLEF);
-}
-
-void
-setcleftenor (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_TENOR_CLEF);
-}
-
-void
-setclefsoprano (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_SOPRANO_CLEF);
-}
-
-void
-setcleffrench (GtkAction* action, DenemoScriptParam *param)
-{
-  DenemoStaff *curstaff = (DenemoStaff *) Denemo.project->movement->currentstaff->data;
-  if (curstaff)
-    dnm_setinitialclef (Denemo.project->movement, curstaff, DENEMO_FRENCH_CLEF);
-}
-
 /*******************************************************************************
 * DURATION COMMANDS
 ******************************************************************************/
