@@ -933,7 +933,7 @@ freeit (gpointer data, gpointer user_data)
 
 
 /************* routines for calling from debug code ***************/
-#include "command/staffops.h"
+#include "command/staff.h"
 
 G_GNUC_UNUSED void
 printobj (objnode * obj)
@@ -1025,15 +1025,15 @@ printmeasure (measurenode * mnode)
       fprintf (stderr, "Empty measure\n");
       return;
     }
-  printobjs (firstobjnode (mnode));
+  printobjs (measure_first_obj_node (mnode));
 }
 
 G_GNUC_UNUSED void
 printmeasures (staffnode * thestaff)
 {
-  GList *measure = firstmeasurenode (thestaff);
+  GList *measure = staff_first_measure_node (thestaff);
   gint measurenum = 1;
-  for (measure = firstmeasurenode (thestaff); measure; measure = measure->next)
+  for (measure = staff_first_measure_node (thestaff); measure; measure = measure->next)
     {
       fprintf (stderr, "*************Measure %d *************\n", measurenum++);
       printmeasure (measure);
@@ -1622,6 +1622,40 @@ findnote_strict (DenemoObject * curObj, gint cursory)
   return NULL;
 }
 
+/* get a fret diagram for the chord at the cursor */
+gchar *get_fretdiagram_as_markup (void)
+{
+DenemoProject *gui = Denemo.project;
+   DenemoObject *curObj;
+      if (!Denemo.project || !(Denemo.project->movement) || !(Denemo.project->movement->currentobject) || !(curObj = Denemo.project->movement->currentobject->data) || !(DENEMO_OBJECT_TYPE_NAME (curObj)))
+        return NULL;
+      if (gui->lilysync != gui->changecount)
+        refresh_lily_cb (NULL, Denemo.project);
+      if (curObj->lilypond)
+        {
+              gchar *text = g_strdup_printf ("\\score{\n\\DenemoGlobalTranspose \\new FretBoards {%s}\\layout{indent=0.0}\n}",  curObj->lilypond);
+              return text;
+        }  
+    return NULL;
+}
+
+/* get a chord symbol for the chord at the cursor */
+gchar *get_fakechord_as_markup (void)
+{
+DenemoProject *gui = Denemo.project;
+   DenemoObject *curObj;
+      if (!Denemo.project || !(Denemo.project->movement) || !(Denemo.project->movement->currentobject) || !(curObj = Denemo.project->movement->currentobject->data) || !(DENEMO_OBJECT_TYPE_NAME (curObj)))
+        return NULL;
+      if (gui->lilysync != gui->changecount)
+        refresh_lily_cb (NULL, Denemo.project);
+      if (curObj->lilypond)
+        {
+            gchar *text = g_strdup_printf ("\\score{\n\\DenemoGlobalTranspose \\new ChordNames {%s}\\layout{indent=0.0}\n}",  curObj->lilypond);
+            return text;
+        }  
+    return NULL;
+}
+
 /* display full information about the object at the cursor */
 GtkWidget *ObjectInfo = NULL;
 static gboolean
@@ -1706,9 +1740,19 @@ display_current_object (void)
                 if (thechord->slur_end_p)
                   selection = g_string_append (selection, _("A slur ends here\n" "There should be a matching start slur earlier.\n"));
                 if (thechord->is_tied)
-                  selection = g_string_append (selection, _("This is tied to the following note or chord.\n" "The following note or chord should have the same pitch"));
+                  selection = g_string_append (selection, _("This is tied to the following note or chord.\n" "The following note or chord should have the same pitch\n"));
+                 if (thechord->crescendo_begin_p)
+                  selection = g_string_append (selection, _("This note begins a crescendo. Use the Right Click → Dynamics menu to control this.\n"));
+                 if (thechord->crescendo_end_p)
+                  selection = g_string_append (selection, _("This note ends a crescendo. Use the Right Click → Dynamics menu to control this.\n"));
+                if (thechord->diminuendo_begin_p)
+                  selection = g_string_append (selection, _("This note begins a diminuendo. Use the Right Click → Dynamics menu to control this.\n"));
+                 if (thechord->diminuendo_end_p)
+                  selection = g_string_append (selection, _("This note ends a diminuendo. Use the Right Click → Dynamics menu to control this.\n"));
+                  
                 if (thechord->is_grace && !(thechord->is_grace & GRACED_NOTE))
-                  selection = g_string_append (selection, _("This is an acciaccatura note\n"));
+                  selection = g_string_append (selection, _("This is an acciaccatura note\n"));    
+                  
                 if (thechord->is_grace & GRACED_NOTE)
                   selection = g_string_append (selection, _("This is an appoggiatura note\n"));
                 if (curObj->isinvisible)
@@ -1737,11 +1781,11 @@ display_current_object (void)
               {
                 selection = g_string_append (selection, _("a rest.\n"));
                 if (thechord->slur_begin_p)
-                  warning = g_string_append (warning, _("This rest has a slur start on it, use the Notes/Rests → Slurs menu to remove it"));
+                  warning = g_string_append (warning, _("This rest has a slur start on it, use the Right Click  → Slurs menu to remove it\n"));
                 if (thechord->slur_end_p)
-                  warning = g_string_append (warning, _("This rest has a slur end on it, use the Notes/Rests → Slurs menu to remove it"));
+                  warning = g_string_append (warning, _("This rest has a slur end on it, use the Right Click → Slurs menu to remove it\n"));
                 if (thechord->is_tied)
-                  warning = g_string_append (warning, _("This rest has a tie starting on it, use the Notes/Rests → Ties menu to remove it"));
+                  warning = g_string_append (warning, _("This rest has a tie starting on it, use the Right Click  → Tied Note to remove it\n"));
 
                   
                 if (curObj->isinvisible)
@@ -1755,7 +1799,7 @@ display_current_object (void)
               append_directives_information (selection, thechord->directives);
                         }
           g_string_append_printf (selection, _("This starts %d/384 quarter notes into the measure and lasts %d/384 quarter notes.\n"), curObj->starttick, curObj->durinticks);
-            if(curObj->lilypond)
+            if(curObj->lilypond && (gui->lilysync == gui->changecount))
                           g_string_append_printf (selection, _("The LilyPond syntax generated is: %s\n"), curObj->lilypond);
 
           }
@@ -1865,6 +1909,19 @@ display_current_object (void)
           }
           break;
         }
+        
+         if (curObj->midi_events)
+            {
+              smf_event_t *event = (smf_event_t *) curObj->midi_events->data;
+              gdouble time = event->time_seconds;
+              gint minutes = time / 60.0;
+              gdouble seconds = time - 60 * minutes;
+              char *buf = event->midi_buffer;
+              g_string_append_printf (selection, _("MIDI information: time %d minutes %1.2f seconds "), minutes, seconds);
+              #define velocity ((*(buf+2))&0x7F)
+              if ((*buf & 0xf0) == 0x90)
+                g_string_append_printf (selection, _("velocity %d\n"), buf[2]);
+          }
 
       if (warning->len)
         {
@@ -2080,8 +2137,13 @@ gchar *choose_file (gchar *title, gchar *startdir, GList *extensions)
                                       GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                                       NULL);
   GtkFileFilter *filter = gtk_file_filter_new();
+  GString *filter_description = g_string_new ("");
   for(extensions;extensions;extensions=extensions->next)
+    {
     gtk_file_filter_add_pattern (filter,(gchar*)extensions->data);
+    g_string_append_printf (filter_description, "%s ", (gchar*)extensions->data);
+    }
+  gtk_file_filter_set_name (filter, filter_description->str);
   gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(dialog), filter);
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER(dialog), startdir);
   
