@@ -17,8 +17,8 @@
 #include "export/exportlilypond.h"
 #include "export/file.h"
 #include "ui/moveviewport.h"
-#include "command/staffops.h"
-#include "command/scoreops.h"
+#include "command/staff.h"
+#include "command/score.h"
 #include "core/utils.h"
 #include "core/exportxml.h"
 #include "export/exportmidi.h"
