@@ -714,7 +714,7 @@ parse_note (xmlNodePtr rootElem, GString ** scripts, gint * staff_for_voice, gin
   else if (is_rest)
     {                           //for the case where a rest is given without a type, just a duration.
      if(is_whole_measure_rest)
-            g_string_append (text, "(d-InsertWholeMeasureRest)");
+            g_string_append (text, "(d-InsertWholeMeasureRest)(d-MoveCursorLeft)");
      else 
             get_rest_for_duration (text, duration, divisions);
 
@@ -1145,7 +1145,7 @@ parse_part (xmlNodePtr rootElem)
   return g_string_free (scripts[0], FALSE);
 }
 
-static gchar *
+static void
 parse_identification (xmlNodePtr rootElem, GString *script)
 {
   
@@ -1198,7 +1198,8 @@ mxmlinput (gchar * filename)
        if (ELEM_NAME_EQ (childElem, "movement-title"))
         {
             gchar *title = xmlNodeListGetString (childElem->doc, childElem->xmlChildrenNode, 1);
-            g_string_append_printf (script, "(d-BookTitle \"%s\")", title);
+            if(title)
+                g_string_append_printf (script, "(d-BookTitle \"%s\")", escape_scheme(title));
         }
      if (ELEM_NAME_EQ (childElem, "identification"))   {
             parse_identification (childElem, script);
@@ -1224,3 +1225,105 @@ mxmlinput (gchar * filename)
   g_string_free (script, TRUE);
   return ret;
 }
+
+/* this code is a utility for generating a scheme structure for inclusion in the MusicGlyph script */
+#ifdef DEVELOPER
+static void parseFont (xmlNodePtr rootElem, GString *script) {
+    xmlNodePtr childElem;g_print("Parse font\n");
+     gchar buffer1[5000],buffer2[5000], current[5000];
+     gboolean new_class = FALSE;
+     current[0] = 0;
+     FOREACH_CHILD_ELEM (childElem, rootElem)
+  {
+     if (ELEM_NAME_EQ (childElem, "glyph"))
+        { 
+            gchar *title = xmlGetProp (childElem, (xmlChar *) "glyph-name");
+            if(title) {
+               
+                gint i, j;
+                gchar *c;
+                
+                for(i=0, j=0, c = title; *c; c++) {
+                    if(*c=='.')
+                        {
+                            for(c++; *c;c++)
+                                buffer2[j++] = *c;
+                            c--;
+                        }
+                    else
+                        buffer1[i++] = *c;
+                }
+                buffer1[i]=buffer2[j] = 0;
+
+                if(*buffer2 == 0)
+                    {
+                        gchar * misc = "...";
+                        new_class = strcmp(current, misc);
+                        strcpy(current, misc);
+                        strcpy(buffer2, buffer1);
+                     }
+                else
+                    if((new_class = strcmp(current, buffer1)))
+                        strcpy (current, buffer1); 
+                if(new_class)
+                            g_string_append_printf(script, "))\n(cons (_ \"%s\") (list \n", current);
+                g_string_append_printf (script, "\t(cons (_ \"%s\") \"%s\")\n", buffer2, title);
+               
+            }
+        } 
+    }
+}
+
+
+static void parseDefs (xmlNodePtr rootElem, GString *script) {
+    xmlNodePtr childElem;g_print("Parse defs\n");
+     FOREACH_CHILD_ELEM (childElem, rootElem)
+  {
+     if (ELEM_NAME_EQ (childElem, "font"))
+        { 
+           parseFont(childElem, script);
+        } 
+    }
+}
+
+gint
+fontinput (gchar * filename)
+{
+  GError *err = NULL;
+  gint ret = 0;
+  xmlDocPtr doc = NULL;
+  xmlNsPtr ns;
+  xmlNodePtr rootElem;
+  /* ignore blanks between nodes that appear as "text" */
+  xmlKeepBlanksDefault (0);
+  /* Try to parse the file. */
+
+  doc = xmlParseFile (filename);
+  if (doc == NULL)
+    {
+      g_warning ("Could not read font file %s", filename);
+      return -1;
+    }
+
+  rootElem = xmlDocGetRootElement (doc);
+  xmlNodePtr childElem;
+  GString *script = g_string_new ("");
+  FOREACH_CHILD_ELEM (childElem, rootElem)
+  {
+      if (ELEM_NAME_EQ (childElem, "defs"))
+        { 
+            parseDefs(childElem, script);
+        }
+     
+  }
+  {
+    FILE *fp = fopen ("/home/rshann/junk.scm", "w");
+    if (fp)
+      {
+        fprintf (fp, ";font glyphs:\n;;%s))\n", script->str);
+        fclose (fp);
+      }
+  }
+  return ret;
+}
+#endif
