@@ -70,6 +70,13 @@ libevince_print (void)
       g_warning ("Typesetting not done? No output filename set.");
       return -1;
   }
+#ifdef G_OS_WIN32
+    infodialog("Direct Printing not available under Windows. Create PDF and print from that");
+    return -1;
+#endif
+  
+  
+  
   gchar *uri = g_filename_to_uri (filename, NULL, &err);
 
   if (err)
@@ -264,7 +271,7 @@ overdraw_print (cairo_t * cr)
           explanation = _("Cursor may have moved to error point in the score.");
           break;
         case 3:
-          headline = _("INVALID!");
+          headline = _("INVALID! try Score->Check Score command.");
           explanation = _("LilyPond could not typeset this score.");
           break;
         }
@@ -1082,6 +1089,11 @@ copy_pdf (void)
                                                     GTK_RESPONSE_REJECT,
                                                     GTK_STOCK_SAVE,
                                                     GTK_RESPONSE_ACCEPT, NULL);
+  GtkFileFilter *filter = gtk_file_filter_new();
+  gtk_file_filter_set_name (filter, _("PDF files"));
+  gtk_file_filter_add_pattern (filter, "*.pdf");
+  gtk_file_filter_add_pattern (filter, "*.PDF");
+  gtk_file_chooser_add_filter (GTK_FILE_CHOOSER(chooser), filter);
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser), outpath);
   gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (chooser), outname);
   gtk_widget_show_all (chooser);
@@ -1095,28 +1107,33 @@ copy_pdf (void)
     {
       gchar *contents;
       gsize length;
+    
+        
       if (g_file_get_contents (get_print_status()->printname_pdf[get_print_status()->cycle], &contents, &length, NULL))
         {
-          if (!g_file_set_contents (filename, contents, length, NULL))
-            {
-              gchar *msg = g_strdup_printf (_("Errno %d:\nCould not copy %s to %s. Perhaps because some other process is using the destination file. Try again with a new location\n"),
-                                            errno,
-                                            get_print_status()->printname_pdf[get_print_status()->cycle],
-                                            filename);
-              warningdialog (msg);
-              g_free (msg);
-            }
-          else
-            {
-              g_debug ("I have copied %s to %s (default was %s)\n", get_print_status()->printname_pdf[get_print_status()->cycle], filename, outname);
-            }
-          g_free (contents);
+            
+            if ((!g_file_test (filename, G_FILE_TEST_EXISTS)) || confirm (_( "PDF creation"), _( "File Exists, overwrite?")))  
+                {          
+                  if (!g_file_set_contents (filename, contents, length, NULL))
+                    {
+                      gchar *msg = g_strdup_printf (_("Errno %d:\nCould not copy %s to %s. Perhaps because some other process is using the destination file. Try again with a new location\n"),
+                                                    errno,
+                                                    get_print_status()->printname_pdf[get_print_status()->cycle],
+                                                    filename);
+                      warningdialog (msg);
+                      g_free (msg);
+                    }
+                  else
+                    {
+                      g_debug ("I have copied %s to %s (default was %s)\n", get_print_status()->printname_pdf[get_print_status()->cycle], filename, outname);
+                    }
+                  g_free (contents);
+                }
         }
       g_free (outpath);
       g_free (outname);
       g_free (filename);
     }
-
 }
 
 static void
@@ -2362,7 +2379,7 @@ get_updates_button (void)
 }
 //pops up a menu of layouts with the action being to typeset that layout. If only one, typeset that.
 static void
-popup_layouts_menu ()
+popup_layouts_menu (void)
 {
   GtkWidget *menu = GetLayoutMenu ();
   if(Denemo.project->custom_scoreblocks || (g_list_length(Denemo.project->standard_scoreblocks)>1)) 
