@@ -80,6 +80,7 @@ SCM scheme_is_cresc_end (SCM);
 SCM scheme_is_dim_start (SCM);
 SCM scheme_is_dim_end (SCM);
 SCM scheme_is_in_selection (void);
+SCM scheme_has_selection (void);
 SCM scheme_is_appending (void);
 SCM scheme_shift_cursor (SCM);
 SCM scheme_get_movement (void);
@@ -179,8 +180,12 @@ SCM scheme_goto_position (SCM movement, SCM staff, SCM measure, SCM object);
 SCM scheme_create_palette_button (SCM palette, SCM lbl, SCM tltp, SCM scrp);
 SCM scheme_set_palette_shape (SCM palette, SCM horizontal, SCM limit);
 SCM scheme_show_palettes (SCM);
+SCM scheme_select_palette (SCM);
+SCM scheme_activate_palette_button (void);
 SCM scheme_get_user_input (SCM label, SCM prompt, SCM init, SCM modal);
 SCM scheme_get_user_input_with_snippets (SCM label, SCM prompt, SCM init, SCM modal);
+SCM scheme_select_font (SCM);
+SCM scheme_select_color (SCM);
 SCM scheme_warningdialog (SCM);
 SCM scheme_infodialog (SCM);
 SCM scheme_progressbar (SCM);
@@ -207,7 +212,7 @@ SCM scheme_get_recorded_midi_on_tick (void);
 SCM scheme_get_note_for_midi_key (SCM);
 SCM scheme_get_recorded_midi_note (void);
 SCM scheme_rewind_recorded_midi (void);
-SCM scheme_get_midi (void);
+SCM scheme_get_midi (SCM bytes);
 SCM scheme_set_midi_capture (SCM);
 SCM scheme_toggle_playalong (void);
 SCM scheme_toggle_conduct (void);
