@@ -9,14 +9,14 @@
 #include <gtk/gtk.h>
 #include <string.h>
 #include "display/calculatepositions.h"
-#include "command/chordops.h"
+#include "command/chord.h"
 #include "command/commandfuncs.h"
 #include "command/contexts.h"
 #include "display/draw.h"
 #include "ui/dialogs.h"
-#include "command/measureops.h"
-#include "command/objops.h"
-#include "command/staffops.h"
+#include "command/measure.h"
+#include "command/object.h"
+#include "command/staff.h"
 #include "core/utils.h"
 
 #define COLUMN_NAME (0)
@@ -77,7 +77,7 @@ clef_change_insert (GtkAction * action, DenemoScriptParam * param)
     {
       enum clefs clef = get_clef_from_name (clefname);
       if (clef != DENEMO_INVALID_CLEF)
-        object_insert (gui, dnm_newclefobj (clef));
+        object_insert (gui, clef_new (clef));
       displayhelper (gui);
     }
 }
@@ -107,7 +107,7 @@ dnm_setinitialclef (DenemoMovement * si, DenemoStaff * curstaffstruct, enum clef
 {
   curstaffstruct->clef.type = clef;
   find_leftmost_staffcontext (curstaffstruct, si);
-  fixnoteheights (curstaffstruct);
+  staff_fix_note_heights (curstaffstruct);
   find_xes_in_all_measures (si);
   displayhelper (Denemo.project);
   score_status(Denemo.project, TRUE);
@@ -179,7 +179,7 @@ clef_change (DenemoProject * gui, actiontype action)
         {
           if (gui->movement->currentobject && ((DenemoObject *) gui->movement->currentobject->data)->type == CLEF)
             deleteobject (NULL, NULL);
-          object_insert (gui, dnm_newclefobj (clef));
+          object_insert (gui, clef_new (clef));
 
         }
       score_status (gui, TRUE);
