@@ -14,8 +14,8 @@
 #include <denemo/denemo.h>
 #include "ui/dialogs.h"
 #include "display/draw.h"
-#include "command/objops.h"
-#include "command/staffops.h"
+#include "command/object.h"
+#include "command/staff.h"
 #include "core/utils.h"
 #include "ui/keysigdialog.h"
 #include "audio/pitchentry.h"
@@ -145,7 +145,7 @@ insert_keysig (keysig_data * kdata)
         {
           for (curstaff = si->thescore; curstaff; curstaff = curstaff->next)
             {
-              curmeasure = g_list_nth (firstmeasurenode (curstaff), si->currentmeasurenum - 1);
+              curmeasure = g_list_nth (staff_first_measure_node (curstaff), si->currentmeasurenum - 1);
               if (curmeasure)
                 {
                     if (curmeasure == si->currentmeasure) 
@@ -160,7 +160,7 @@ insert_keysig (keysig_data * kdata)
                         
                   if (curmeasure == si->currentmeasure)
                     si->currentobject = g_list_nth ((objnode *) curmeasure->data, si->cursor_x);
-                  showwhichaccidentalswholestaff ((DenemoStaff *) curstaff->data);
+                  staff_show_which_accidentals ((DenemoStaff *) curstaff->data);
                 }
             }                   /* End for */
         }                       /* End if */
@@ -168,7 +168,7 @@ insert_keysig (keysig_data * kdata)
         {
 
           object_insert (Denemo.project, newkey = dnm_newkeyobj (tokey - mode, isminor, mode));
-          showwhichaccidentalswholestaff ((DenemoStaff *) si->currentstaff->data);
+          staff_show_which_accidentals ((DenemoStaff *) si->currentstaff->data);
         }
       si->cursor_appending = FALSE;
       if (newkey)
@@ -257,7 +257,7 @@ key_change_insert (GtkAction * action, DenemoScriptParam * param)
       if (valid)
         {
           object_insert (gui, dnm_newkeyobj (tokey, isminor, 0));
-          showwhichaccidentalswholestaff (gui->movement->currentstaff->data);
+          staff_show_which_accidentals (gui->movement->currentstaff->data);
           displayhelper (gui);
         }
       gchar *key;
