@@ -7,9 +7,9 @@
 
 #include "command/commandfuncs.h"
 #include "core/kbd-custom.h"
-#include "command/staffops.h"
+#include "command/staff.h"
 #include "core/utils.h"
-#include "command/selectops.h"
+#include "command/select.h"
 #include "command/lilydirectives.h"
 #include "command/lyric.h"
 #include "ui/moveviewport.h"
@@ -215,7 +215,7 @@ get_placement_from_coordinates (struct placement_info *pi, gdouble x, gdouble y,
   pi->nextmeasure = ((si->system_height > 0.5 || x_to_explain > GPOINTER_TO_INT (mwidthiterator->data)) && pi->measure_number >= rightmeasurenum);
 
   pi->the_staff = g_list_nth (si->thescore, pi->staff_number - 1);
-  pi->the_measure = nth_measure_node_in_staff (pi->the_staff, pi->measure_number - 1);
+  pi->the_measure = staff_nth_measure_node (pi->the_staff, pi->measure_number - 1);
   if (pi->the_measure != NULL)
     {                           /*check to make sure user did not click on empty space */
       obj_iterator = (objnode *) pi->the_measure->data;
@@ -793,14 +793,16 @@ scorearea_button_press (GtkWidget * widget, GdkEventButton * event)
                   if (Denemo.prefs.learning)
                     MouseGestureShow(_("Left Click on blue."), _("This adds one sharp."),
                       MouseGesture);
+                if (pi.nextmeasure || confirm (_("Initial Key Signature Change"), _("Sharpen Keysignature?")))
                   call_out_to_guile ("(d-SharpenInitialKeysigs)");
                 }
               else if (offset > 0 && (offset < STAFF_HEIGHT))
                 {
                   if (Denemo.prefs.learning)
                     MouseGestureShow(_("Left Click on red."), _("This adds one flat."),
-                      MouseGesture);                                  
-                  call_out_to_guile ("(d-FlattenInitialKeysigs)");
+                      MouseGesture);
+                  if (pi.nextmeasure || confirm (_("Initial Key Signature Change"), _("Flatten Keysignature?")))
+                    call_out_to_guile ("(d-FlattenInitialKeysigs)");
                 }
             }
           else
