@@ -85,14 +85,14 @@ struct name_and_function denemo_commands[] = {
 
 
 
-  {NULL, "No Tooltip yet", N_("InsertDuplet"), "insert_duplet", N_("Insert Duplet")},
-  {NULL, "Inserts a Start Triplet object and an End Tuplet object and places the cursor between these two", N_("InsertTriplet"), "insert_triplet", N_("Insert Triplet")},
-  {NULL, "Inserts an Start Triplet object, which makes the notes following take 2/3 of their written duration. Later in this measure there should be an End Tuplet object.", N_("StartTriplet"), "start_triplet", N_("Start Triplet")},
-  {NULL, "Inserts an End Tuplet object, which terminates a tuplet started earlier in this measure.", N_("EndTuplet"), "end_tuplet", N_("End Tuplet")},
+  {NULL, "No Tooltip yet", N_("InsertDuplet"), "duplet_insert", N_("Insert Duplet")},
+  {NULL, "Inserts a Start Triplet object and an End Tuplet object and places the cursor between these two", N_("InsertTriplet"), "triplet_insert", N_("Insert Triplet")},
+  {NULL, "Inserts an Start Triplet object, which makes the notes following take 2/3 of their written duration. Later in this measure there should be an End Tuplet object.", N_("StartTriplet"), "triplet_start", N_("Start Triplet")},
+  {NULL, "Inserts an End Tuplet object, which terminates a tuplet started earlier in this measure.", N_("EndTuplet"), "tuplet_end", N_("End Tuplet")},
   {NULL, "No Tooltip yet", N_("InsertQuadtuplet"), "insert_quadtuplet", N_("Insert Quadruplet")},
-  {NULL, "No Tooltip yet", N_("InsertQuintuplet"), "insert_quintuplet", N_("Insert Quintuplet")},
-  {NULL, "No Tooltip yet", N_("InsertSextuplet"), "insert_sextuplet", N_("Insert Sextuplet")},
-  {NULL, "No Tooltip yet", N_("InsertSeptuplet"), "insert_septuplet", N_("Insert Septuplet")},
+  {NULL, "No Tooltip yet", N_("InsertQuintuplet"), "quintuplet_insert", N_("Insert Quintuplet")},
+  {NULL, "No Tooltip yet", N_("InsertSextuplet"), "sextuplet_insert", N_("Insert Sextuplet")},
+  {NULL, "No Tooltip yet", N_("InsertSeptuplet"), "septuplet_insert", N_("Insert Septuplet")},
   {NULL, "Add a note to the current chord\\nThe cursor position determines which note to add", N_("AddNoteToChord"), "add_tone_key", "Add note"},
   {NULL, "Remove a note from the current chord, based on the cursor position", N_("RemoveNoteFromChord"), "remove_tone_key", "Remove note"},
 
@@ -130,19 +130,19 @@ struct name_and_function denemo_commands[] = {
   {NULL, "No Tooltip yet", N_("ShorterStaffs"), "adjust_staff_less_height_key", N_("Shorter Staffs")},
   {NULL, "No Tooltip yet", N_("TallerStaffs"), "adjust_staff_more_height_key", N_("Taller Staffs")},
 
-  {NULL, "No Tooltip yet", N_("InsertTrebleClef"), "newcleftreble", N_("New Treble Clef")},
-  {NULL, "No Tooltip yet", N_("InsertBassClef"), "newclefbass", N_("New Bass Clef")},
-  {NULL, "No Tooltip yet", N_("Insertg8clef"), "newclefg8", N_("New G8 Clef")},
-  {NULL, "No Tooltip yet", N_("InsertAltoClef"), "newclefalto", N_("New Alto Clef")},
-  {NULL, "No Tooltip yet", N_("InsertTenorClef"), "newcleftenor", N_("New Tenor Clef")},
-  {NULL, "No Tooltip yet", N_("InsertSopranoClef"), "newclefsoprano", N_("New Soprano Clef")},
+  {NULL, "No Tooltip yet", N_("InsertTrebleClef"), "clef_new_treble", N_("New Treble Clef")},
+  {NULL, "No Tooltip yet", N_("InsertBassClef"), "clef_new_bass", N_("New Bass Clef")},
+  {NULL, "No Tooltip yet", N_("Insertg8clef"), "clef_new_g8", N_("New G8 Clef")},
+  {NULL, "No Tooltip yet", N_("InsertAltoClef"), "clef_new_alto", N_("New Alto Clef")},
+  {NULL, "No Tooltip yet", N_("InsertTenorClef"), "clef_new_tenor", N_("New Tenor Clef")},
+  {NULL, "No Tooltip yet", N_("InsertSopranoClef"), "clef_new_soprano", N_("New Soprano Clef")},
 
-  {NULL, "No Tooltip yet", N_("SetInitialTrebleClef"), "setcleftreble", N_("Set Treble Clef")},
-  {NULL, "No Tooltip yet", N_("SetInitialBassClef"), "setclefbass", N_("Set Bass Clef")},
-  {NULL, "No Tooltip yet", N_("SetInitialg8clef"), "setclefg8", N_("Set G8 Clef")},
-  {NULL, "No Tooltip yet", N_("SetInitialAltoClef"), "setclefalto", N_("Set Alto Clef")},
-  {NULL, "No Tooltip yet", N_("SetInitialTenorClef"), "setcleftenor", N_("Set Tenor Clef")},
-  {NULL, "No Tooltip yet", N_("SetInitialSopranoClef"), "setclefsoprano", N_("Set Soprano Clef")},
+  {NULL, "No Tooltip yet", N_("SetInitialTrebleClef"), "clef_set_treble", N_("Set Treble Clef")},
+  {NULL, "No Tooltip yet", N_("SetInitialBassClef"), "clef_set_bass", N_("Set Bass Clef")},
+  {NULL, "No Tooltip yet", N_("SetInitialg8clef"), "clef_set_g8", N_("Set G8 Clef")},
+  {NULL, "No Tooltip yet", N_("SetInitialAltoClef"), "clef_set_alto", N_("Set Alto Clef")},
+  {NULL, "No Tooltip yet", N_("SetInitialTenorClef"), "clef_set_tenor", N_("Set Tenor Clef")},
+  {NULL, "No Tooltip yet", N_("SetInitialSopranoClef"), "clef_set_soprano", N_("Set Soprano Clef")},
 
   {NULL, "No Tooltip yet", N_("Insert22Time"), "newtimesig22", N_("Insert 2/2 Time")},
   {NULL, "No Tooltip yet", N_("Insert32Time"), "newtimesig32", N_("Insert 3/2 Time")},
@@ -166,68 +166,68 @@ struct name_and_function denemo_commands[] = {
   {NULL, "No Tooltip yet", N_("Set68Time"), "settimesig68", N_("Set 6/8 Time")},
   {NULL, "No Tooltip yet", N_("Set128Time"), "settimesig128", N_("Set 12/8 Time")},
   {NULL, "No Tooltip yet", N_("Set98Time"), "settimesig98", N_("Set 9/8 Time")},
-  {NULL, "No Tooltip yet", N_("InsertCmaj"), "newkeysigcmaj", N_("Insert Cmaj")},
-  {NULL, "No Tooltip yet", N_("InsertGmaj"), "newkeysiggmaj", N_("Insert Gmaj")},
-  {NULL, "No Tooltip yet", N_("InsertDmaj"), "newkeysigdmaj", N_("Insert Dmaj")},
-  {NULL, "No Tooltip yet", N_("InsertAmaj"), "newkeysigamaj", N_("Insert Amaj")},
-  {NULL, "No Tooltip yet", N_("InsertEmaj"), "newkeysigemaj", N_("Insert Emaj")},
-  {NULL, "No Tooltip yet", N_("InsertBmaj"), "newkeysigbmaj", N_("Insert Bmaj")},
-  {NULL, "No Tooltip yet", N_("InsertFSharpmaj"), "newkeysigfsharpmaj", N_("Insert F# Major")},
-  {NULL, "No Tooltip yet", N_("InsertCSharpmaj"), "newkeysigcsharpmaj", N_("Insert C# Major")},
-  {NULL, "No Tooltip yet", N_("InsertFmaj"), "newkeysigfmaj", N_("Insert F Major")},
-  {NULL, "No Tooltip yet", N_("InsertBflatmaj"), "newkeysigbflatmaj", N_("Insert Bb Major")},
-  {NULL, "No Tooltip yet", N_("InsertEflatmaj"), "newkeysigeflatmaj", N_("Insert Eb Major")},
-  {NULL, "No Tooltip yet", N_("InsertAflatmaj"), "newkeysigaflatmaj", N_("Insert Ab Major")},
-  {NULL, "No Tooltip yet", N_("InsertDflatmaj"), "newkeysigdflatmaj", N_("Insert Db Major")},
-  {NULL, "No Tooltip yet", N_("InsertGflatmaj"), "newkeysiggflatmaj", N_("Insert Gb Major")},
-  {NULL, "No Tooltip yet", N_("InsertCflatmaj"), "newkeysigcflatmaj", N_("Insert Cb Major")},
-  {NULL, "No Tooltip yet", N_("InsertAmin"), "newkeysigamin", N_("Insert A Minor")},
-  {NULL, "No Tooltip yet", N_("InsertEmin"), "newkeysigemin", N_("Insert E Minor")},
-  {NULL, "No Tooltip yet", N_("InsertBmin"), "newkeysigbmin", N_("Insert B Minor")},
-  {NULL, "No Tooltip yet", N_("InsertFSharpmin"), "newkeysigfsharpmin", N_("Insert F# Minor")},
-  {NULL, "No Tooltip yet", N_("InsertCSharpmin"), "newkeysigcsharpmin", N_("Insert C# Minor")},
-  {NULL, "No Tooltip yet", N_("InsertGSharpmin"), "newkeysiggsharpmin", N_("Insert G# Minor")},
-  {NULL, "No Tooltip yet", N_("InsertDSharpmin"), "newkeysigdsharpmin", N_("Insert D# Minor")},
-  {NULL, "No Tooltip yet", N_("InsertASharpmin"), "newkeysigasharpmin", N_("Insert A# Minor")},
-  {NULL, "No Tooltip yet", N_("InsertDmin"), "newkeysigdmin", N_("Insert D Minor")},
-  {NULL, "No Tooltip yet", N_("InsertGmin"), "newkeysiggmin", N_("Insert G Minor")},
-  {NULL, "No Tooltip yet", N_("InsertCmin"), "newkeysigcmin", N_("Insert C Minor")},
-  {NULL, "No Tooltip yet", N_("InsertFmin"), "newkeysigfmin", N_("Insert F Minor")},
-  {NULL, "No Tooltip yet", N_("InsertBflatmin"), "newkeysigbflatmin", N_("Insert Bb Minor")},
-  {NULL, "No Tooltip yet", N_("InsertEflatmin"), "newkeysigeflatmin", N_("Insert Eb Minor")},
-  {NULL, "No Tooltip yet", N_("InsertAflatmin"), "newkeysigaflatmin", N_("Insert Ab Minor")},
+  {NULL, "No Tooltip yet", N_("InsertCmaj"), "keysig_new_cmaj", N_("Insert Cmaj")},
+  {NULL, "No Tooltip yet", N_("InsertGmaj"), "keysig_new_gmaj", N_("Insert Gmaj")},
+  {NULL, "No Tooltip yet", N_("InsertDmaj"), "keysig_new_dmaj", N_("Insert Dmaj")},
+  {NULL, "No Tooltip yet", N_("InsertAmaj"), "keysig_new_amaj", N_("Insert Amaj")},
+  {NULL, "No Tooltip yet", N_("InsertEmaj"), "keysig_new_emaj", N_("Insert Emaj")},
+  {NULL, "No Tooltip yet", N_("InsertBmaj"), "keysig_new_bmaj", N_("Insert Bmaj")},
+  {NULL, "No Tooltip yet", N_("InsertFSharpmaj"), "keysig_new_fsharpmaj", N_("Insert F# Major")},
+  {NULL, "No Tooltip yet", N_("InsertCSharpmaj"), "keysig_new_csharpmaj", N_("Insert C# Major")},
+  {NULL, "No Tooltip yet", N_("InsertFmaj"), "keysig_new_fmaj", N_("Insert F Major")},
+  {NULL, "No Tooltip yet", N_("InsertBflatmaj"), "keysig_new_bflatmaj", N_("Insert Bb Major")},
+  {NULL, "No Tooltip yet", N_("InsertEflatmaj"), "keysig_new_eflatmaj", N_("Insert Eb Major")},
+  {NULL, "No Tooltip yet", N_("InsertAflatmaj"), "keysig_new_aflatmaj", N_("Insert Ab Major")},
+  {NULL, "No Tooltip yet", N_("InsertDflatmaj"), "keysig_new_dflatmaj", N_("Insert Db Major")},
+  {NULL, "No Tooltip yet", N_("InsertGflatmaj"), "keysig_new_gflatmaj", N_("Insert Gb Major")},
+  {NULL, "No Tooltip yet", N_("InsertCflatmaj"), "keysig_new_cflatmaj", N_("Insert Cb Major")},
+  {NULL, "No Tooltip yet", N_("InsertAmin"), "keysig_new_amin", N_("Insert A Minor")},
+  {NULL, "No Tooltip yet", N_("InsertEmin"), "keysig_new_emin", N_("Insert E Minor")},
+  {NULL, "No Tooltip yet", N_("InsertBmin"), "keysig_new_bmin", N_("Insert B Minor")},
+  {NULL, "No Tooltip yet", N_("InsertFSharpmin"), "keysig_new_fsharpmin", N_("Insert F# Minor")},
+  {NULL, "No Tooltip yet", N_("InsertCSharpmin"), "keysig_new_csharpmin", N_("Insert C# Minor")},
+  {NULL, "No Tooltip yet", N_("InsertGSharpmin"), "keysig_new_gsharpmin", N_("Insert G# Minor")},
+  {NULL, "No Tooltip yet", N_("InsertDSharpmin"), "keysig_new_dsharpmin", N_("Insert D# Minor")},
+  {NULL, "No Tooltip yet", N_("InsertASharpmin"), "keysig_new_asharpmin", N_("Insert A# Minor")},
+  {NULL, "No Tooltip yet", N_("InsertDmin"), "keysig_new_dmin", N_("Insert D Minor")},
+  {NULL, "No Tooltip yet", N_("InsertGmin"), "keysig_new_gmin", N_("Insert G Minor")},
+  {NULL, "No Tooltip yet", N_("InsertCmin"), "keysig_new_cmin", N_("Insert C Minor")},
+  {NULL, "No Tooltip yet", N_("InsertFmin"), "keysig_new_fmin", N_("Insert F Minor")},
+  {NULL, "No Tooltip yet", N_("InsertBflatmin"), "keysig_new_bflatmin", N_("Insert Bb Minor")},
+  {NULL, "No Tooltip yet", N_("InsertEflatmin"), "keysig_new_eflatmin", N_("Insert Eb Minor")},
+  {NULL, "No Tooltip yet", N_("InsertAflatmin"), "keysig_new_aflatmin", N_("Insert Ab Minor")},
 
   //Functions to Set Initial Key Sig
-  {NULL, "No Tooltip yet", N_("SetInitialCmaj"), "setkeysigcmaj", N_("Set Initial Keysig to C Major")},
-  {NULL, "No Tooltip yet", N_("SetInitialGmaj"), "setkeysiggmaj", N_("Set Initial Keysig to G Major")},
-  {NULL, "No Tooltip yet", N_("SetInitialDmaj"), "setkeysigdmaj", N_("Set D Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialAmaj"), "setkeysigamaj", N_("Set A Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialEmaj"), "setkeysigemaj", N_("Set E Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialBmaj"), "setkeysigbmaj", N_("Set B Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialFSharpmaj"), "setkeysigfsharpmaj", N_("Set F# Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialCSharpmaj"), "setkeysigcsharpmaj", N_("Set C# Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialFmaj"), "setkeysigfmaj", N_("Set F Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialBflatmaj"), "setkeysigbflatmaj", N_("Set Bb Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialEflatmaj"), "setkeysigeflatmaj", N_("Set Eb Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialAflatmaj"), "setkeysigaflatmaj", N_("Set Ab Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialDflatmaj"), "setkeysigdflatmaj", N_("Set Db Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialGflatmaj"), "setkeysiggflatmaj", N_("Set Gb Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialCflatmaj"), "setkeysigcflatmaj", N_("Set Cb Major as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialAmin"), "setkeysigamin", N_("Set A Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialEmin"), "setkeysigemin", N_("Set E Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialBmin"), "setkeysigbmin", N_("Set B Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialFSharpmin"), "setkeysigfsharpmin", N_("Set F# Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialCSharpmin"), "setkeysigcsharpmin", N_("Set C# Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialGSharpmin"), "setkeysiggsharpmin", N_("Set G# Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialDSharpmin"), "setkeysigdsharpmin", N_("Set D# Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialASharpmin"), "setkeysigasharpmin", N_("Set A# Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialDmin"), "setkeysigdmin", N_("Set D Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialGmin"), "setkeysiggmin", N_("Set G Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialCmin"), "setkeysigcmin", N_("Set C Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialFmin"), "setkeysigfmin", N_("Set F Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialBflatmin"), "setkeysigbflatmin", N_("Set Bb Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialEflatmin"), "setkeysigeflatmin", N_("Set Eb Minor as Initial Keysig")},
-  {NULL, "No Tooltip yet", N_("SetInitialAflatmin"), "setkeysigaflatmin", N_("Set Ab Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialCmaj"), "keysig_set_cmaj", N_("Set Initial Keysig to C Major")},
+  {NULL, "No Tooltip yet", N_("SetInitialGmaj"), "keysig_set_gmaj", N_("Set Initial Keysig to G Major")},
+  {NULL, "No Tooltip yet", N_("SetInitialDmaj"), "keysig_set_dmaj", N_("Set D Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialAmaj"), "keysig_set_amaj", N_("Set A Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialEmaj"), "keysig_set_emaj", N_("Set E Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialBmaj"), "keysig_set_bmaj", N_("Set B Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialFSharpmaj"), "keysig_set_fsharpmaj", N_("Set F# Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialCSharpmaj"), "keysig_set_csharpmaj", N_("Set C# Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialFmaj"), "keysig_set_fmaj", N_("Set F Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialBflatmaj"), "keysig_set_bflatmaj", N_("Set Bb Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialEflatmaj"), "keysig_set_eflatmaj", N_("Set Eb Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialAflatmaj"), "keysig_set_aflatmaj", N_("Set Ab Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialDflatmaj"), "keysig_set_dflatmaj", N_("Set Db Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialGflatmaj"), "keysig_set_gflatmaj", N_("Set Gb Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialCflatmaj"), "keysig_set_cflatmaj", N_("Set Cb Major as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialAmin"), "keysig_set_amin", N_("Set A Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialEmin"), "keysig_set_emin", N_("Set E Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialBmin"), "keysig_set_bmin", N_("Set B Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialFSharpmin"), "keysig_set_fsharpmin", N_("Set F# Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialCSharpmin"), "keysig_set_csharpmin", N_("Set C# Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialGSharpmin"), "keysig_set_gsharpmin", N_("Set G# Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialDSharpmin"), "keysig_set_dsharpmin", N_("Set D# Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialASharpmin"), "keysig_set_asharpmin", N_("Set A# Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialDmin"), "keysig_set_dmin", N_("Set D Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialGmin"), "keysig_set_gmin", N_("Set G Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialCmin"), "keysig_set_cmin", N_("Set C Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialFmin"), "keysig_set_fmin", N_("Set F Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialBflatmin"), "keysig_set_bflatmin", N_("Set Bb Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialEflatmin"), "keysig_set_eflatmin", N_("Set Eb Minor as Initial Keysig")},
+  {NULL, "No Tooltip yet", N_("SetInitialAflatmin"), "keysig_set_aflatmin", N_("Set Ab Minor as Initial Keysig")},
 
 
   {NULL, "Sets the start point for a selection,\\nthe end point of the selection is unaltered", N_("SetMark"), "set_mark", N_("Set Mark")},
@@ -340,14 +340,14 @@ struct name_and_function denemo_commands[] = {
 
 
 
-  {NULL, "Inserts a new staff before the current staff", N_("AddBefore"), "newstaffbefore", N_("Add Staff Before")},
-  {NULL, "Inserts/Adds a new staff after the current staff", N_("AddAfter"), "dnm_newstaffafter", N_("Add Staff After")},
-  {NULL, "Inserts a new staff at the top of the score", N_("AddInitial"), "newstaffinitial", N_("Add Initial Staff")},
-  {NULL, "Inserts a new staff at the end of the score", N_("AddLast"), "newstafflast", N_("Add Last Staff")},
+  {NULL, "Inserts a new staff before the current staff", N_("AddBefore"), "staff_new_before", N_("Add Staff Before")},
+  {NULL, "Inserts/Adds a new staff after the current staff", N_("AddAfter"), "staff_new_after", N_("Add Staff After")},
+  {NULL, "Inserts a new staff at the top of the score", N_("AddInitial"), "staff_new_initial", N_("Add Initial Staff")},
+  {NULL, "Inserts a new staff at the end of the score", N_("AddLast"), "staff_new_last", N_("Add Last Staff")},
   {NULL, "Deletes the staff before the current staff", N_("DeleteBefore"), "delete_staff_before", N_("Delete Staff Before")},
   {NULL, "Deletes the current staff", N_("DeleteStaff"), "delete_staff_current", N_("Delete Current Staff")},
   {NULL, "Deletes the staff after the current staff", N_("DeleteAfter"), "delete_staff_after", N_("Delete Staff After")},
-  {NULL, "Adds a new voice (part), to the current staff. It is tricky to switch between the voices. Suggest to use merge staffs", "AddVoice", "dnm_newstaffvoice", N_("Add Voice")},
+  {NULL, "Adds a new voice (part), to the current staff. It is tricky to switch between the voices. Suggest to use merge staffs", "AddVoice", "staff_new_voice", N_("Add Voice")},
   {"GTK_STOCK_PROPERTIES", "Change the built-in properties of the current staff", N_("StaffProperties"), "staff_properties_change_cb", N_("Built-in Staff Properties")},
   {NULL, "Insert", N_("InsertMenu"), NULL, NULL},
   {NULL, "Menu:\\nClef", N_("Clef"), NULL, NULL},
